@@ -24,6 +24,7 @@ class HTMLForm(UserDict):
 
     action = ''
     method = ''
+    id = ''
     url = ''
     data = {}
 
@@ -41,6 +42,8 @@ class HTMLForm(UserDict):
             self.action = form_element.xpath('./@action')[0]
         if len(form_element.xpath('./@method')) > 0:
             self.method = form_element.xpath('./@method')[0]
+        if len(form_element.xpath('./@id')) > 0:
+            self.id = form_element.xpath('./@id')[0]
 
         # Grab all the inputs
         self.data = {}
@@ -53,7 +56,7 @@ class HTMLForm(UserDict):
 
             # Look for default values on select inputs
             if type(einp) is lxml.html.SelectElement:
-                if einp.xpath('./option[@selected]'):
+                if einp.xpath('./option[@selected]/@value'):
                     inp.value = einp.xpath('./option[@selected]/@value')[0]
 
             if inp.name:
@@ -105,6 +108,11 @@ class HTMLForm(UserDict):
             self.action = self.url
         elif self.action == u.path:
             self.action = self.url
+        elif self.action.split('?')[0] == u.path:
+            if self.action.startswith('/'):
+                self.action = 'http://' + u.netloc + self.action
+            else:
+                self.action = 'http://' + u.netloc + '/' + self.action
         else:
             if u.netloc not in self.action:
                 path = '/'.join(u.path.split('/')[1:-1])
